@@ -23,7 +23,6 @@
 -- Foundation, 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 ----------------------------------------------------------------------*/
 
-#include <assert.h>
 #include <float.h>
 #include <math.h>
 #include <string.h>
@@ -172,7 +171,7 @@ int glp_read_mps(char *fname)
                   lb = ub = cqe->val;
                   break;
                default:
-                  assert(type != type);
+                  insist(type != type);
             }
             glp_set_bounds(GLP_ROW, type, lb, ub);
          }
@@ -212,7 +211,7 @@ int glp_read_mps(char *fname)
                      lb -= fabs(cqe->val);
                   break;
                default:
-                  assert(type != type);
+                  insist(type != type);
             }
             glp_set_bounds(GLP_ROW, lb == ub ? GLP_FX : GLP_DB, lb, ub);
          }
