@@ -23,13 +23,12 @@
 -- Foundation, 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 ----------------------------------------------------------------------*/
 
-#include <assert.h>
 #include <math.h>
 #include "glpk.h"
 #include "glprsm.h"
 
 /*----------------------------------------------------------------------
--- glp_simplex - solve problem by means of revised simplex method.
+-- glp_simplex - solve problem by means of the revised simplex method.
 --
 -- *Synopsis*
 --
@@ -84,9 +83,9 @@
 -- *Returns*
 --
 -- 0 - no errors. This code means that the solver has successfully
---     finished solving the problem (note that, for example, of the
+--     finished solving the problem (note that, for example, if the
 --     problem has no feasible solution, the code returned by the solver
---     will be equal to zero;
+--     will be equal to zero);
 -- 1 - it's not possible to start solving the problem because of
 --     incorrect data. All diagnostics was sent to stderr;
 -- 2 - the solver is not able to solve the problem. All diagnostics was
@@ -108,18 +107,18 @@ int glp_simplex(void)
       print("Solving LP problem...");
       rsm = NULL;
       /* extract relevant control parameters */
-      assert(glp_get_ipar("obj_dir", &obj_dir) == 0);
-      assert(glp_get_cpar("obj_row", obj_row) == 0);
-      assert(glp_get_ipar("scale", &scale) == 0);
-      assert(glp_get_ipar("spx_form", &form) == 0);
-      assert(glp_get_ipar("spx_relax", &relax) == 0);
-      assert(glp_get_ipar("spx_steep", &steep) == 0);
-      assert(glp_get_ipar("spx_use_dual", &use_dual) == 0);
-      assert(glp_get_ipar("sum_aij", &sum_aij) == 0);
-      assert(glp_get_rpar("tol_aij", &tol_aij) == 0);
-      assert(glp_get_rpar("tol_bnd", &tol_bnd) == 0);
-      assert(glp_get_rpar("tol_dj", &tol_dj) == 0);
-      assert(glp_get_rpar("tol_piv", &tol_piv) == 0);
+      insist(glp_get_ipar("obj_dir", &obj_dir) == 0);
+      insist(glp_get_cpar("obj_row", obj_row) == 0);
+      insist(glp_get_ipar("scale", &scale) == 0);
+      insist(glp_get_ipar("spx_form", &form) == 0);
+      insist(glp_get_ipar("spx_relax", &relax) == 0);
+      insist(glp_get_ipar("spx_steep", &steep) == 0);
+      insist(glp_get_ipar("spx_use_dual", &use_dual) == 0);
+      insist(glp_get_ipar("sum_aij", &sum_aij) == 0);
+      insist(glp_get_rpar("tol_aij", &tol_aij) == 0);
+      insist(glp_get_rpar("tol_bnd", &tol_bnd) == 0);
+      insist(glp_get_rpar("tol_dj", &tol_dj) == 0);
+      insist(glp_get_rpar("tol_piv", &tol_piv) == 0);
       /* renumber and count rows */
       m = 0;
       for (ret = glp_first_item(GLP_ROW); ret == 0;
@@ -156,7 +155,7 @@ int glp_simplex(void)
             glp_get_seqn(what, &seqn);
             glp_get_bounds(what, &type, &lb, &ub);
             k = (kase == 0 ? 0 : m) + seqn;
-            assert(1 <= k && k <= m+n);
+            insist(1 <= k && k <= m+n);
             switch (type)
             {  case GLP_FR:
                   rsm->type[k] = LP_FR;
@@ -173,14 +172,14 @@ int glp_simplex(void)
                case GLP_DB:
                   rsm->type[k] = LP_DB;
                   rsm->lb[k] = lb, rsm->ub[k] = ub;
-                  assert(lb < ub);
+                  insist(lb < ub);
                   break;
                case GLP_FX:
                   rsm->type[k] = LP_FX;
                   rsm->lb[k] = rsm->ub[k] = lb;
                   break;
                default:
-                  assert(type != type);
+                  insist(type != type);
             }
          }
       }
@@ -207,9 +206,9 @@ int glp_simplex(void)
       if (obj_row[0] == '\0')
          rsm->obj = 0;
       else
-      {  assert(glp_find_item(GLP_ROW, obj_row) == 0);
-         assert(glp_get_seqn(GLP_ROW, &rsm->obj) == 0);
-         assert(1 <= rsm->obj && rsm->obj <= m);
+      {  insist(glp_find_item(GLP_ROW, obj_row) == 0);
+         insist(glp_get_seqn(GLP_ROW, &rsm->obj) == 0);
+         insist(1 <= rsm->obj && rsm->obj <= m);
       }
       /* --- quadratic programming segment --- */
       rsm->qp_flag = 0;
@@ -253,7 +252,7 @@ int glp_simplex(void)
                rsm->tagn[j] = LP_NS;
                break;
             default:
-               assert(rsm->type[k] != rsm->type[k]);
+               insist(rsm->type[k] != rsm->type[k]);
          }
       }
       /* --- simplex method segment --- */
@@ -276,7 +275,7 @@ int glp_simplex(void)
             rsm->rfi->tech = RFI_FT;
             break;
          default:
-            assert(form != form);
+            insist(form != form);
       }
       rsm->bbar = ucalloc(1+m, sizeof(double));
       rsm->cost = ucalloc(1+m+n, sizeof(double));
@@ -320,7 +319,7 @@ int glp_simplex(void)
          {  if (ee == NULL || ee->j < e->j)
                ee = e;
             else
-            {  assert(ee != e && ee->j == e->j);
+            {  insist(ee != e && ee->j == e->j);
                if (!sum_aij)
                {  print("glp_simplex: constraint matrix has multiplets")
                      ;
@@ -343,7 +342,7 @@ int glp_simplex(void)
       /* compute the initial basis solution (if required) */
       if (obj_dir == GLP_INI)
       {  /* the initial basis matrix is a unity matrix */
-         assert(rsm_invert(rsm) == 0);
+         insist(rsm_invert(rsm) == 0);
          /* compute initial values of basis variables */
          rsm_set_bbar(rsm);
          /* check initial solution for primal feasibility */
@@ -385,7 +384,7 @@ sing: {  error("Numerical problems with basis matrix");
                case LP_NL: rsm->cost[k] = +1.0; break;
                case LP_NU: rsm->cost[k] = -1.0; break;
                case LP_NS: rsm->cost[k] =  0.0; break;
-               default: assert(rsm->tagn[j] != rsm->tagn[j]);
+               default: insist(rsm->tagn[j] != rsm->tagn[j]);
             }
          }
          ret = rsm_dual_opt(rsm);
@@ -413,7 +412,7 @@ sing: {  error("Numerical problems with basis matrix");
             /* numerical problems with basis matrix */
             goto sing;
          default:
-            assert(ret != ret);
+            insist(ret != ret);
       }
       /* searching for optimal solution */
       print("Searching for optimal solution...");
@@ -447,7 +446,7 @@ sing: {  error("Numerical problems with basis matrix");
             /* numerical problems with basis matrix */
             goto sing;
          default:
-            assert(ret != ret);
+            insist(ret != ret);
       }
 done: /* delete revised simplex method common block */
       if (rsm != NULL)
@@ -488,11 +487,11 @@ done: /* delete revised simplex method common block */
 static void store_sol(int status)
 {     int m = rsm->m, n = rsm->n, round, i, j, k, kase, ret;
       double tol_bnd, tol_dj;
-      assert(glp_get_ipar("round", &round) == 0);
-      assert(glp_get_rpar("tol_bnd", &tol_bnd) == 0);
-      assert(glp_get_rpar("tol_dj", &tol_dj) == 0);
+      insist(glp_get_ipar("round", &round) == 0);
+      insist(glp_get_rpar("tol_bnd", &tol_bnd) == 0);
+      insist(glp_get_rpar("tol_dj", &tol_dj) == 0);
       /* set the solution status */
-      assert(glp_set_ipar("status", status) == 0);
+      insist(glp_set_ipar("status", status) == 0);
       /* set the original objective function */
       for (k = 1; k <= m+n; k++) rsm->cost[k] = 0.0;
       if (rsm->obj != 0) rsm->cost[rsm->obj] = 1.0;
@@ -511,7 +510,7 @@ static void store_sol(int status)
             glp_get_seqn(what, &seqn);
             glp_get_bounds(what, &type, &lb, &ub);
             k = (kase == 0 ? 0 : m) + seqn;
-            assert(1 <= k && k <= m+n);
+            insist(1 <= k && k <= m+n);
             if (rsm->posx[k] > 0)
             {  /* basis variable */
                i = +rsm->posx[k]; /* x[k] = xB[i] */
@@ -530,7 +529,7 @@ static void store_sol(int status)
                   case LP_NU: tagx = GLP_NU; break;
                   case LP_NF: tagx = GLP_NF; break;
                   case LP_NS: tagx = GLP_NS; break;
-                  default: assert(rsm->tagn[j] != rsm->tagn[j]);
+                  default: insist(rsm->tagn[j] != rsm->tagn[j]);
                }
                valx = rsm_get_xn(rsm, j);
                if (fabs(rsm->cbar[j]) < tol_dj)
@@ -554,7 +553,7 @@ static void store_sol(int status)
                problem */
             if (rsm->obj != 0) dx /= rsm->R[rsm->obj];
             /* assign tagx, valx, and dx to x[k] */
-            assert(glp_set_activity(what, tagx, valx, dx) == 0);
+            insist(glp_set_activity(what, tagx, valx, dx) == 0);
          }
       }
       return;
