@@ -23,7 +23,6 @@
 -- Foundation, 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 ----------------------------------------------------------------------*/
 
-#include <assert.h>
 #include <errno.h>
 #include <math.h>
 #include <stdio.h>
@@ -161,7 +160,7 @@ int glp_write_mps(char *fname)
             case GLP_UP: type = 'L'; break;
             case GLP_DB: type = 'E'; break;
             case GLP_FX: type = 'E'; break;
-            default: assert(type != type);
+            default: insist(type != type);
          }
          fprintf(fp, " %c  %s\n", type, row_name[seqn]);
       }
@@ -209,7 +208,7 @@ int glp_write_mps(char *fname)
                case GLP_UP: rhs = ub;  break;
                case GLP_DB: rhs = (ub > 0.0 ? lb : ub); break;
                case GLP_FX: rhs = lb;  break;
-               default: assert(type != type);
+               default: insist(type != type);
             }
             if (rhs == 0.0) continue;
             if (!flag) fprintf(fp, "RHS\n"), flag = 1;
@@ -283,7 +282,7 @@ int glp_write_mps(char *fname)
                      col_name[seqn], mps_number(lb));
                   break;
                default:
-                  assert(type != type);
+                  insist(type != type);
             }
          }
       }
@@ -360,10 +359,10 @@ alas:    /* nothing came of it */
          {  char *t;
             sprintf(alias[k], "%c%7d", what == GLP_ROW ? 'R' : 'C', k);
             for (t = alias[k]; *t; t++) if (*t == ' ') *t = '~';
-            assert(find_by_key(tree, alias[k]) == NULL);
+            insist(find_by_key(tree, alias[k]) == NULL);
          }
 fini:    /* enter the generated name to the symbol table */
-         assert(strlen(alias[k]) <= 8);
+         insist(strlen(alias[k]) <= 8);
          node = insert_by_key(tree, alias[k]);
          node->type = k;
       }
@@ -385,7 +384,7 @@ static char *mps_number(double val)
             sprintf(numb, "%.*E", n, val);
          else
             sprintf(numb, "%.*G", n, val);
-         assert(strlen(numb) <= 255);
+         insist(strlen(numb) <= 255);
          e = strrchr(numb, 'E');
          if (e != NULL) sprintf(e+1, "%d", atoi(e+1));
          if (strlen(numb) <= 12) return numb;
