@@ -23,7 +23,6 @@
 -- Foundation, 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 ----------------------------------------------------------------------*/
 
-#include <assert.h>
 #include <stddef.h>
 #include "glprsm.h"
 
@@ -59,7 +58,7 @@ double *rsm_btran(RSM *rsm, double z[])
       else if (rsm->rfi != NULL)
          rfi_btran(rsm->rfi, z);
       else
-         assert(2 + 2 == 5);
+         insist(2 + 2 == 5);
       return z;
 }
 
