@@ -23,7 +23,6 @@
 -- Foundation, 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 ----------------------------------------------------------------------*/
 
-#include <assert.h>
 #include <stddef.h>
 #include "glprsm.h"
 #include "glpset.h"
@@ -72,14 +71,14 @@ int rsm_change_basis(RSM *rsm)
       if (p < 0)
       {  /* xN[q] goes from the current bound to the opposite one */
          k = rsm->indn[q]; /* x[k] = xN[q] */
-         assert(rsm->type[k] == LP_DB);
-         assert(rsm->tagn[q] == LP_NL || rsm->tagn[q] == LP_NU);
+         insist(rsm->type[k] == LP_DB);
+         insist(rsm->tagn[q] == LP_NL || rsm->tagn[q] == LP_NU);
          rsm->tagn[q] = (rsm->tagn[q] == LP_NL) ? LP_NU : LP_NL;
       }
       else
       {  /* xB[p] leaves the basis, xN[q] enters the basis */
-         assert(1 <= p && p <= m);
-         assert(1 <= q && q <= n);
+         insist(1 <= p && p <= m);
+         insist(1 <= q && q <= n);
          kp = rsm->indb[p]; kq = rsm->indn[q];
          rsm->posx[kq] = +p; rsm->posx[kp] = -q;
          rsm->indb[p]  = kq; rsm->indn[q]  = kp;
@@ -90,7 +89,7 @@ int rsm_change_basis(RSM *rsm)
          else if (rsm->rfi != NULL)
             ret = update_rfi(rsm->rfi, rsm->p);
          else
-            assert(2 + 2 == 5);
+            insist(2 + 2 == 5);
          /* if representation became inaccurate or too long, reinvert
             the basis matrix */
          if (ret != 0) ret = rsm_invert(rsm);
