@@ -23,7 +23,6 @@
 -- Foundation, 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 ----------------------------------------------------------------------*/
 
-#include <assert.h>
 #include "glprsm.h"
 
 /*----------------------------------------------------------------------
@@ -44,36 +43,36 @@ void rsm_check_basis(RSM *rsm)
       for (k = 1; k <= m+n; k++)
       {  if (rsm->posx[k] > 0)
          {  i = +rsm->posx[k]; /* xB[i] = x[k] */
-            assert(1 <= i && i <= m);
-            assert(rsm->indb[i] == k);
+            insist(1 <= i && i <= m);
+            insist(rsm->indb[i] == k);
          }
          else if (rsm->posx[k] < 0)
          {  j = -rsm->posx[k]; /* xN[j] = x[k] */
-            assert(1 <= j && j <= n);
-            assert(rsm->indn[j] == k);
+            insist(1 <= j && j <= n);
+            insist(rsm->indn[j] == k);
             switch (rsm->type[k])
             {  case LP_FR:
-                  assert(rsm->tagn[j] == LP_NF);
+                  insist(rsm->tagn[j] == LP_NF);
                   break;
                case LP_LO:
-                  assert(rsm->tagn[j] == LP_NL);
+                  insist(rsm->tagn[j] == LP_NL);
                   break;
                case LP_UP:
-                  assert(rsm->tagn[j] == LP_NU);
+                  insist(rsm->tagn[j] == LP_NU);
                   break;
                case LP_DB:
-                  assert(rsm->tagn[j] == LP_NL || rsm->tagn[j] == LP_NU)
+                  insist(rsm->tagn[j] == LP_NL || rsm->tagn[j] == LP_NU)
                      ;
                   break;
                case LP_FX:
-                  assert(rsm->tagn[j] == LP_NS);
+                  insist(rsm->tagn[j] == LP_NS);
                   break;
                default:
-                  assert(rsm->tagn[j] != rsm->tagn[j]);
+                  insist(rsm->tagn[j] != rsm->tagn[j]);
             }
          }
          else
-            assert(rsm->posx[k] != rsm->posx[k]);
+            insist(rsm->posx[k] != rsm->posx[k]);
       }
       return;
 }
