@@ -23,7 +23,6 @@
 -- Foundation, 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 ----------------------------------------------------------------------*/
 
-#include <assert.h>
 #include <float.h>
 #include <math.h>
 #include "glprsm.h"
@@ -104,7 +103,7 @@ double rsm_dual_col(RSM *rsm, double tol)
             continue;
          }
          else
-            assert(rsm->tagn[j] != rsm->tagn[j]);
+            insist(rsm->tagn[j] != rsm->tagn[j]);
          /* if reduced costs of xN[j] (i.e. dual variable) slightly
             violates its bound, temp is negative; in this case it is
             assumed that reduced cost is exactly on its bound (i.e.
