@@ -23,7 +23,6 @@
 -- Foundation, 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 ----------------------------------------------------------------------*/
 
-#include <assert.h>
 #include <stddef.h>
 #include "glprsm.h"
 #include "glpset.h"
@@ -60,7 +59,7 @@ double rsm_exact_dzeta(RSM *rsm, int i)
 {     ELEM *e;
       int m = rsm->m, n = rsm->n, j, k;
       double *bi, *ai, t;
-      assert(1 <= i && i <= m);
+      insist(1 <= i && i <= m);
       /* compute i-th row of the inverse inv(B) */
       bi = ucalloc(1+m, sizeof(double));
       bi[i] = 1.0;
