@@ -23,7 +23,6 @@
 -- Foundation, 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 ----------------------------------------------------------------------*/
 
-#include <assert.h>
 #include <stddef.h>
 #include "glprsm.h"
 #include "glpset.h"
@@ -64,7 +63,7 @@ double rsm_exact_gamma(RSM *rsm, int j)
 {     ELEM *e;
       int m = rsm->m, n = rsm->n, k;
       double *aj, t;
-      assert(1 <= j && j <= n);
+      insist(1 <= j && j <= n);
       k = rsm->indn[j]; /* x[k] = xN[j] */
       /* aj = - inv(B) * N[j] */
       aj = ucalloc(1+m, sizeof(double));
