@@ -23,7 +23,6 @@
 -- Foundation, 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 ----------------------------------------------------------------------*/
 
-#include <assert.h>
 #include <stdlib.h>
 #include "glprsm.h"
 #include "glpset.h"
@@ -210,7 +209,7 @@ int rsm_find_feas(RSM *rsm)
             if (rsm->type[k] == orig_type[k]) continue;
             /* if type[k] differs from orig_type[k], x[k] is implicit
                artificial variable (which should be basis variable!) */
-            assert(rsm->posx[k] > 0);
+            insist(rsm->posx[k] > 0);
             if (rsm->type[k] == LP_LO)
             {  /* x[k] should be decreased, since actually x[k] violates
                   its upper bound */
@@ -222,7 +221,7 @@ int rsm_find_feas(RSM *rsm)
                rsm->cost[k] = -1.0;
             }
             else
-               assert(rsm->type[k] != rsm->type[k]);
+               insist(rsm->type[k] != rsm->type[k]);
          }
          /* compute simplex multipliers */
          rsm_set_pi(rsm);
@@ -257,7 +256,7 @@ int rsm_find_feas(RSM *rsm)
             k = rsm->indb[p]; /* x[k] = xB[p] */
             if (rsm->type[k] != orig_type[k])
             {  /* x[k] is implicit artificial variable */
-               assert(rsm->tagp == LP_NL || rsm->tagp == LP_NU);
+               insist(rsm->tagp == LP_NL || rsm->tagp == LP_NU);
                rsm->tagp = (rsm->tagp == LP_NL ? LP_NU : LP_NL);
                rsm->type[k] = orig_type[k];
                rsm->lb[k]   = orig_lb[k];
