@@ -23,7 +23,6 @@
 -- Foundation, 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 ----------------------------------------------------------------------*/
 
-#include <assert.h>
 #include <stddef.h>
 #include "glprsm.h"
 
@@ -66,7 +65,7 @@ double *rsm_ftran(RSM *rsm, double z[], int save)
       else if (rsm->rfi != NULL)
          rfi_ftran(rsm->rfi, z, save);
       else
-         assert(2 + 2 == 5);
+         insist(2 + 2 == 5);
       return z;
 }
 
