@@ -23,7 +23,6 @@
 -- Foundation, 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 ----------------------------------------------------------------------*/
 
-#include <assert.h>
 #include "glprsm.h"
 #include "glpset.h"
 
@@ -43,7 +42,7 @@
 double rsm_get_xn(RSM *rsm, int j)
 {     int n = rsm->n, k;
       double t;
-      assert(1 <= j && j <= n);
+      insist(1 <= j && j <= n);
       k = rsm->indn[j]; /* x[k] = xN[j] */
       switch (rsm->tagn[j])
       {  case LP_NL:
@@ -55,7 +54,7 @@ double rsm_get_xn(RSM *rsm, int j)
          case LP_NS:
             t = rsm->lb[k]; break;
          default:
-            assert(rsm->tagn[j] != rsm->tagn[j]);
+            insist(rsm->tagn[j] != rsm->tagn[j]);
       }
       return t;
 }
