@@ -23,7 +23,6 @@
 -- Foundation, 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 ----------------------------------------------------------------------*/
 
-#include <assert.h>
 #include <float.h>
 #include <math.h>
 #include "glprsm.h"
@@ -134,7 +133,7 @@ up_1:       temp = ((ub[k] + gap(ub[k])) - bbar[i]) / rsm->aq[i];
             if (rsm->aq[i] < 0.0) goto lo_1; else goto up_1;
          }
          else
-            assert(rsm->type[k] != rsm->type[k]);
+            insist(rsm->type[k] != rsm->type[k]);
          /* if xB[i] slightly violates its (relaxed!) bound, temp is
             negative; in this case it is assumes thst xB[i] is exactly
             on its (relaxed!) bound, so temp is replaced by zero */
@@ -183,7 +182,7 @@ up_2:       temp = (ub[k] - bbar[i]) / rsm->aq[i];
             tag = LP_NS;
          }
          else
-            assert(rsm->type[k] != rsm->type[k]);
+            insist(rsm->type[k] != rsm->type[k]);
          /* if xB[i] slightly violates its (original!) bound, temp is
             negative; in this case it is assumed that xB[i] is exactly
             on its (original!) bound, so temp is replaced by zero */
