@@ -23,7 +23,6 @@
 -- Foundation, 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 ----------------------------------------------------------------------*/
 
-#include <assert.h>
 #include <stddef.h>
 #include "glprsm.h"
 
@@ -54,7 +53,7 @@ int rsm_invert(RSM *rsm)
       else if (rsm->rfi != NULL)
          ret = build_rfi(rsm->rfi, rsm->A, rsm->indb);
       else
-         assert(2 + 2 == 5);
+         insist(2 + 2 == 5);
       return ret;
 }
 
