@@ -23,7 +23,6 @@
 -- Foundation, 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 ----------------------------------------------------------------------*/
 
-#include <assert.h>
 #include <float.h>
 #include <math.h>
 #include "glprsm.h"
@@ -129,7 +128,7 @@ up:         temp = (rsm->ub[k] - rsm->bbar[i]) / rsm->aq[i];
             tag = LP_NS;
          }
          else
-            assert(rsm->type[k] != rsm->type[k]);
+            insist(rsm->type[k] != rsm->type[k]);
          /* if xB[i] slightly violates its bound, temp is negative;
             in this case it is assumes that xB[i] is exactly on its
             bound, therefore temp is replaced by zero */
