@@ -23,7 +23,6 @@
 -- Foundation, 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 ----------------------------------------------------------------------*/
 
-#include <assert.h>
 #include <stddef.h>
 #include "glprsm.h"
 
@@ -60,7 +59,7 @@ void rsm_set_aq(RSM *rsm)
 {     ELEM *e;
       int m = rsm->m, n = rsm->n, i, k;
       double *z = rsm->aq;
-      assert(1 <= rsm->q && rsm->q <= n);
+      insist(1 <= rsm->q && rsm->q <= n);
       k = rsm->indn[rsm->q]; /* x[k] = xN[q] */
       /* z = N[q] */
       for (i = 1; i <= m; i++) z[i] = 0.0;
