@@ -23,7 +23,6 @@
 -- Foundation, 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 ----------------------------------------------------------------------*/
 
-#include <assert.h>
 #include "glprsm.h"
 
 /*----------------------------------------------------------------------
@@ -47,7 +46,7 @@
 
 void rsm_set_bp(RSM *rsm)
 {     int m = rsm->m, p = rsm->p, i;
-      assert(1 <= p && p <= m);
+      insist(1 <= p && p <= m);
       for (i = 1; i <= m; i++) rsm->bp[i] = 0.0;
       rsm->bp[p] = 1.0;
       rsm_btran(rsm, rsm->bp);
