@@ -23,7 +23,6 @@
 -- Foundation, 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 ----------------------------------------------------------------------*/
 
-#include <assert.h>
 #include <stddef.h>
 #include "glprsm.h"
 
@@ -135,7 +134,7 @@ void rsm_update_gamma(RSM *rsm, double y[], double w[])
 {     ELEM *e;
       int m = rsm->m, n = rsm->n, p = rsm->p, q = rsm->q, i, j, k;
       double *gamma = rsm->gamma, apj, t, t1, t2;
-      assert(1 <= p && p <= m && 1 <= q && q <= n);
+      insist(1 <= p && p <= m && 1 <= q && q <= n);
       gamma[q] = 1.0;
       for (i = 1; i <= m; i++) gamma[q] += rsm->aq[i] * rsm->aq[i];
       for (i = 1; i <= m; i++) y[i] = 0.0;
