@@ -91,7 +91,7 @@ struct GLPWKSP
          string, the first range vector is used */
       int mps_skip_empty; /* used by the glp_write_mps routine */
       /* if this flag is set, the routine writes all columns, ibcluding
-         empty ones (i.e. those, which have no constraint coefficients);
+         empty ones (i.e. those which have no constraint coefficients);
          otherwise the routine write only non-empty columns */
       int mps_use_names; /* used by the glp_write_mps routine */
       /* if this flag is set, the routine tries to generate standard
@@ -111,8 +111,8 @@ struct GLPWKSP
       /* problem name (1 to 255 chars) */
       int round; /* used by the solver */
       /* if this flag is set, the solver replaces values of those basis
-         variables, which are near to zero, by exact zeros; otherwise
-         the solver remains values of all basis variables "as is" */
+         variables which are near to zero, by exact zeros; otherwise the
+         solver remains values of all basis variables "as is" */
       int scale; /* used by the solver */
       /* if this flag is set, the solver performs automatic scaling the
          problem before solving; otherwise the scaling is not used */
@@ -148,20 +148,20 @@ struct GLPWKSP
          column indices) by their sum before solving the problem;
          otherwise the solver considers multiplets as incorrect data */
       double tol_aij; /* used by the solver */
-      /* this parameter specifies the absolute tolerance, which is used
+      /* this parameter specifies the absolute tolerance which is used
          by the solver to drop small elements of the original constraint
          matrix; if this tolerance is equal to zero, the solver uses the
          original matrix without any changes */
       double tol_bnd; /* used by the solver */
-      /* this parameter specifies the relative tolerance, which is used
+      /* this parameter specifies the relative tolerance which is used
          by the solver for checking primal feasibility of the current
          basis solution */
       double tol_dj; /* used by the solver */
-      /* this parameter specifies the relative tolerance, which is used
+      /* this parameter specifies the relative tolerance which is used
          by the solver for checking dual feasibility of the current
          basis solution */
       double tol_piv; /* used by the solver */
-      /* this parameter specifies the relative tolerance, which is used
+      /* this parameter specifies the relative tolerance which is used
          by the solver for pivoting */
 };
 
