@@ -27,7 +27,7 @@
 #define _GLPK_H
 
 #define GLP_MAX_NAME 255
-/* maximal length of item name (except '\0') */
+/* maximal length of item name (not including '\0') */
 
 #define GLP_NO       0     /* false */
 #define GLP_YES      1     /* true */
@@ -106,6 +106,9 @@ extern int glp_get_seqn(int what, int *seqn);
 extern int glp_initialize(void);
 /* initialize GLPK application program interface */
 
+extern int glp_interior(void);
+/* solve problem by means of the interior point method */
+
 extern int glp_new_coef(double val);
 /* create new constraint coefficient */
 
@@ -143,7 +146,7 @@ extern int glp_set_seqn(int what, int seqn);
 /* set seqn attribute of the current row or column */
 
 extern int glp_simplex(void);
-/* solve problem by means of revised simplex method */
+/* solve problem by means of the revised simplex method */
 
 extern int glp_terminate(void);
 /* terminate GLPK application program interface */
