@@ -30,6 +30,7 @@
 #define err_flag              glp_err_flag
 #define error                 glp_error
 #define fault                 glp_fault
+#define _insist               glp_insist
 #define mem_flag              glp_mem_flag
 #define mem_limit             glp_mem_limit
 #define mem_total             glp_mem_total
@@ -62,8 +63,14 @@ extern void error(char *fmt, ...);
 extern void fault(char *fmt, ...);
 /* print error message and terminate program execution */
 
+#define insist(expr) \
+   ((void)((expr) || (_insist(#expr, __FILE__, __LINE__), 1)))
+
+extern void _insist(char *expr, char *file, int line);
+/* check for logical condition */
+
 /* some processors need data to be properly aligned; the align_boundary
-   macro defines the boundary, which should fit for all data types; the
+   macro defines the boundary which should fit for all data types; the
    align_datasize macro allows enlarging size of data item in order the
    immediately following data of any type should be properly aligned */
 
