@@ -23,7 +23,6 @@
 -- Foundation, 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 ----------------------------------------------------------------------*/
 
-#include <assert.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -50,7 +49,7 @@ static char *out_fname = "";
 -- display_help - display help.
 --
 -- This routine displays help information about the program as it is
--- required by the GNU Coding Standard. */
+-- required by the GNU Coding Standards. */
 
 static void display_help(char *my_name)
 {     printf("Usage: %s [options...] mps-file\n", my_name);
@@ -110,7 +109,7 @@ static void display_help(char *my_name)
 -- display_version - display version.
 --
 -- This routine displays version information for the program as it is
--- required by the GNU Coding Standard. */
+-- required by the GNU Coding Standards. */
 
 static void display_version(void)
 {     printf("%s\n", version);
@@ -133,13 +132,13 @@ static void process_cmdline(int argc, char *argv[])
 {     int k;
       for (k = 1; k < argc; k++)
       {  if (strcmp(argv[k], "--ini") == 0)
-            assert(glp_set_ipar("obj_dir", GLP_INI) == 0);
+            insist(glp_set_ipar("obj_dir", GLP_INI) == 0);
          else if (strcmp(argv[k], "--any") == 0)
-            assert(glp_set_ipar("obj_dir", GLP_ANY) == 0);
+            insist(glp_set_ipar("obj_dir", GLP_ANY) == 0);
          else if (strcmp(argv[k], "--min") == 0)
-            assert(glp_set_ipar("obj_dir", GLP_MIN) == 0);
+            insist(glp_set_ipar("obj_dir", GLP_MIN) == 0);
          else if (strcmp(argv[k], "--max") == 0)
-            assert(glp_set_ipar("obj_dir", GLP_MAX) == 0);
+            insist(glp_set_ipar("obj_dir", GLP_MAX) == 0);
          else if (strcmp(argv[k], "-o") == 0 ||
                   strcmp(argv[k], "--output") == 0)
          {  k++;
@@ -154,38 +153,38 @@ static void process_cmdline(int argc, char *argv[])
             out_fname = argv[k];
          }
          else if (strcmp(argv[k], "--textbook") == 0)
-         {  assert(glp_set_ipar("scale", GLP_NO) == 0);
-            assert(glp_set_ipar("spx_form", GLP_EFI) == 0);
-            assert(glp_set_ipar("spx_use_dual", GLP_NO) == 0);
-            assert(glp_set_ipar("spx_steep", GLP_NO) == 0);
-            assert(glp_set_ipar("spx_relax", GLP_NO) == 0);
+         {  insist(glp_set_ipar("scale", GLP_NO) == 0);
+            insist(glp_set_ipar("spx_form", GLP_EFI) == 0);
+            insist(glp_set_ipar("spx_use_dual", GLP_NO) == 0);
+            insist(glp_set_ipar("spx_steep", GLP_NO) == 0);
+            insist(glp_set_ipar("spx_relax", GLP_NO) == 0);
          }
          else if (strcmp(argv[k], "--scale") == 0)
-            assert(glp_set_ipar("scale", GLP_YES) == 0);
+            insist(glp_set_ipar("scale", GLP_YES) == 0);
          else if (strcmp(argv[k], "--noscale") == 0)
-            assert(glp_set_ipar("scale", GLP_NO) == 0);
+            insist(glp_set_ipar("scale", GLP_NO) == 0);
          else if (strcmp(argv[k], "--efi") == 0)
-            assert(glp_set_ipar("spx_form", GLP_EFI) == 0);
+            insist(glp_set_ipar("spx_form", GLP_EFI) == 0);
          else if (strcmp(argv[k], "--rfi-bg") == 0)
-            assert(glp_set_ipar("spx_form", GLP_RFI_BG) == 0);
+            insist(glp_set_ipar("spx_form", GLP_RFI_BG) == 0);
          else if (strcmp(argv[k], "--rfi-ft") == 0)
-            assert(glp_set_ipar("spx_form", GLP_RFI_FT) == 0);
+            insist(glp_set_ipar("spx_form", GLP_RFI_FT) == 0);
          else if (strcmp(argv[k], "--primal") == 0)
-            assert(glp_set_ipar("spx_use_dual", GLP_NO) == 0);
+            insist(glp_set_ipar("spx_use_dual", GLP_NO) == 0);
          else if (strcmp(argv[k], "--dual") == 0)
-            assert(glp_set_ipar("spx_use_dual", GLP_YES) == 0);
+            insist(glp_set_ipar("spx_use_dual", GLP_YES) == 0);
          else if (strcmp(argv[k], "--steep") == 0)
-            assert(glp_set_ipar("spx_steep", GLP_YES) == 0);
+            insist(glp_set_ipar("spx_steep", GLP_YES) == 0);
          else if (strcmp(argv[k], "--nosteep") == 0)
-            assert(glp_set_ipar("spx_steep", GLP_NO) == 0);
+            insist(glp_set_ipar("spx_steep", GLP_NO) == 0);
          else if (strcmp(argv[k], "--relax") == 0)
-            assert(glp_set_ipar("spx_relax", GLP_YES) == 0);
+            insist(glp_set_ipar("spx_relax", GLP_YES) == 0);
          else if (strcmp(argv[k], "--norelax") == 0)
-            assert(glp_set_ipar("spx_relax", GLP_NO) == 0);
+            insist(glp_set_ipar("spx_relax", GLP_NO) == 0);
          else if (strcmp(argv[k], "--sum") == 0)
-            assert(glp_set_ipar("sum_aij", GLP_YES) == 0);
+            insist(glp_set_ipar("sum_aij", GLP_YES) == 0);
          else if (strcmp(argv[k], "--nosum") == 0)
-            assert(glp_set_ipar("sum_aij", GLP_NO) == 0);
+            insist(glp_set_ipar("sum_aij", GLP_NO) == 0);
          else if (strcmp(argv[k], "-h") == 0 ||
                   strcmp(argv[k], "--help") == 0)
             display_help(argv[0]);
@@ -236,7 +235,7 @@ int main(int argc, char *argv[])
       /* solve LP problem */
       t_start = clock();
       if (glp_simplex() != 0)
-      {  fprintf(stderr, "Can't solve LP problem\n");
+      {  fprintf(stderr, "Can't solve the problem because of errors\n");
          exit(EXIT_FAILURE);
       }
       /* display statistics */
